
### CHANGE THIS LINE TO THE LOCATION OF THE
### UNZIPPED REPLICATION ARCHIVE

setwd('C:/Projects/Warren_IO_2014_rep')

library(foreign)
library(Hmisc)
library(BMA)
library(MontgomeryNyhan)
library(Matching)


###########
### IDI ###
###########

### Load predictions from regession models
### (Note: This file is generated by "Warren_IO_regs.do")

pred_data <- read.dta("Warren_IO_predictions.dta")

x1 <- pred_data$pr1 # Model 1
x2 <- pred_data$pr2 # Model 2
x3 <- pred_data$pr3 # Model 3
y <-  pred_data$onset

improveProb(x1, x2, y)
improveProb(x1, x3, y)
improveProb(x2, x3, y)


###########
### BMA ###
###########

#Load regression data
reg_data <- read.dta("Warren_IO_reg_data.dta")

#Define data matrices
attach(reg_data)
x <- as.data.frame(cbind(onset, mdi, lgdpl, litli, seduli, telephli, pfl, 
                         larea, lmtn, lpopl, oil2l, deml, deml2, ethfracl, relfracl, 
                         pcyrs, spline1, spline2, spline3))
detach(reg_data)

y <- x$onset

x$onset <- NULL

bma <- aic.glmMN(x, y, glm.family="binomial", strict=FALSE, factor.type=TRUE, occam.window=FALSE, 
                  all.none.list=list(c(16,17,18)), OR.fix=200, nbest=100000)

summary(bma)



################
### MATCHING ###
################

### Treatment = Media Density Index ###

attach(reg_data)
mdata <- as.data.frame(cbind(onset, mdi, mdi_p50, lgdpl, lgdpl_p50, litli, seduli, telephli, pfl, 
                             larea, lmtn, lpopl, oil2l, deml, deml2, ethfracl, relfracl, 
                             pcyrs, spline1, spline2, spline3))
detach(reg_data)

mdata <- na.omit(mdata)

ps  <- glm(mdi_p50 ~ lgdpl + litli + seduli + telephli + pfl +
           larea + lmtn + lpopl + oil2l + 
           deml + deml2 + ethfracl + relfracl + 
           pcyrs + spline1 + spline2 + spline3, 
           family = binomial, data = mdata)

X <- cbind(ps$fitted, mdata$lgdpl, mdata$litli, mdata$seduli, mdata$telephli, mdata$pfl, 
           mdata$larea, mdata$lmtn, mdata$lpopl, mdata$oil2l, 
           mdata$deml, mdata$ethfracl, mdata$relfracl, 
           mdata$pcyrs)

BalanceMatrix <- cbind(mdata$lgdpl, mdata$litli, mdata$seduli, mdata$telephli, mdata$pfl, 
                       mdata$larea, mdata$lmtn, mdata$lpopl, mdata$oil2l, 
                       mdata$deml, mdata$deml2, mdata$ethfracl, mdata$relfracl, 
                       mdata$pcyrs, mdata$spline1, mdata$spline2, mdata$spline3)

treat <- mdata$mdi_p50

Y <- mdata$onset

genout <- GenMatch(Tr=treat, X=X, BalanceMatrix=BalanceMatrix, estimand="ATT", 
                   M=1, pop.size=1000, max.generations=100, wait.generations=5)

match_mdi <- Match(Y=Y, Tr=treat, X=X, estimand="ATT", 
                   M=1, BiasAdjust=FALSE, Weight.matrix=genout)

summary(match_mdi)



### Treatment = GDP per capita ###

ps  <- glm(lgdpl_p50 ~ mdi + litli + seduli + telephli + pfl +
           larea + lmtn + lpopl + oil2l + 
           deml + deml2 + ethfracl + relfracl + 
           pcyrs + spline1 + spline2 + spline3, 
           family = binomial, data = mdata)

X <- cbind(ps$fitted, mdata$mdi, mdata$litli, mdata$seduli, mdata$telephli, mdata$pfl, 
           mdata$larea, mdata$lmtn, mdata$lpopl, mdata$oil2l, 
           mdata$deml, mdata$ethfracl, mdata$relfracl, 
           mdata$pcyrs)

BalanceMatrix <- cbind(mdata$mdi, mdata$litli, mdata$seduli, mdata$telephli, mdata$pfl, 
                       mdata$larea, mdata$lmtn, mdata$lpopl, mdata$oil2l, 
                       mdata$deml, mdata$deml2, mdata$ethfracl, mdata$relfracl, 
                       mdata$pcyrs, mdata$spline1, mdata$spline2, mdata$spline3)

treat <- mdata$lgdpl_p50

genout <- GenMatch(Tr=treat, X=X, BalanceMatrix=BalanceMatrix, estimand="ATT", 
                   M=1, pop.size=1000, max.generations=100, wait.generations=5)

match_gdp <- Match(Y=Y, Tr=treat, X=X, estimand="ATT", 
                   M=1, BiasAdjust=FALSE, Weight.matrix=genout)

summary(match_gdp)



